# pybase

This is a python package that encapsulates functions that  I often use, which contain

* [X] basic datastructure (list, dict, ...) ops
* [ ] color utils
* [ ] draw rect, polygon ... utils
* [ ] file ops
* [ ] 

